@@ -4,7 +4,7 @@ try:
     from enum import StrEnum
 
 except ImportError:
-    from core_https.utils import StrEnum
+    from core_mixins.compatibility import StrEnum
 
 
 class StatusInfo(StrEnum):
